@@ -23,11 +23,13 @@ module Chake
 
     def run(cmd)
       printf "%#{Node.max_node_name_length}s: $ %s\n", node.hostname, cmd
-      output = IO.popen(command_runner + [cmd], err: [:child, :out])
-      output.each_line do |line|
+      io = IO.popen(command_runner + ['/bin/sh'], mode='w+', eer: [:child, :out])
+      io.write(cmd)
+      io.close_write
+      io.each_line do |line|
         printf "%#{Node.max_node_name_length}s: %s\n", node.hostname, line.strip
       end
-      output.close
+      io.close
       if $?
         status = $?.exitstatus
         if status != 0
